# Copyright 1999-2005 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

inherit linux-mod eutils autotools

DESCRIPTION="Driver for Genius Wizardpen Tablets"
HOMEPAGE="http://code.google.com/p/linuxgenius/"
SRC_URI="http://launchpad.net/wizardpen/trunk/0.8/+download/xorg-input-wizardpen-0.8.0.tar.gz"

DEPEND=""
RDEPEND="x11-base/xorg-server"

LICENSE="GPL-2"
SLOT="0"
KEYWORDS="~x86 ~amd64"
IUSE="hal udev"

RESTRICT="nomirror"

src_unpack() {
	if kernel_is 2 4; then
		die "You must use 2.6.X kernel with ${PN}"
	fi
	if ! linux_chkconfig_module INPUT_EVDEV
	then
		if ! linux_chkconfig_present INPUT_EVDEV
			then
			eerror "${PN} requires evdev support for USB tablets"
			eerror "In your .config: CONFIG_INPUT_EVDEV=y or CONFIG_INPUT_EVDEV=m"
			eerror "Through 'make menuconfig':"
						eerror "Device Drivers-> Input device support-> [*] Event interface or"
						eerror "Device Drivers-> Input device support-> [M] Event interface"
						eerror ""
						eerror "If compiled as modules add evdev to /etc/modules.autoload/kernel-2.6"
						die "Please build evdev support first"
		fi
	fi
	if ! linux_chkconfig_present USB_HID
	then
		eerror "${PN} requires USB Human Interface Device support for USB tablets"
		eerror "In your .config: CONFIG_USB_HID=y or CONFIG_USB_HID=m"
		eerror "Through 'make menuconfig':"
		eerror "Device Drivers-> USB support-> [*] USB Human Interface Device (full HID) support or"
		eerror "Device Drivers-> USB support-> [M] USB Human Interface Device (full HID) support"
		eerror ""
		eerror "If compiled as modules add usbhid to /etc/modules.autoload/kernel-2.6"
		die "Please build USB HID support first"
	fi
	unpack ${A}
	cd "${WORKDIR}/xorg-input-${PN}-${PV/_/-}"
	rm aclocal.m4
	eautoreconf
}

src_compile() {
	cd "${WORKDIR}/xorg-input-${PN}-${PV/_/-}"
	econf || die "econf failed"
	emake || die "emake failed"
}

src_install() {
	cd "${WORKDIR}/xorg-input-${PN}-${PV/_/-}"
	exeinto /usr/lib/xorg/modules/drivers/
	doexe src/.libs/wizardpen_drv.so

	exeinto /usr/bin
	doexe calibrate/wizardpen-calibrate

	doman man/wizardpen.4

	use udev && {
		insinto /etc/udev/rules.d
		doins udev/67-xorg-wizardpen.rules
		doins udev/70-xorg-wizardpen-settings.rules
	}

	use hal && {
		insinto /etc/hal/fdi/policy
		doins hal/10-wizardpen-devices.fdi
		doins hal/11-wizardpen-config.fdi
	}
}

pkg_postinst() {
	einfo ""
	einfo "You can set tablet working area useing wizardpen-calibrate tool, see"
	einfo "README and INSTALL files from /usr/share/doc/${P} for more details."
	einfo ""
}
